@@ -142,7 +142,7 @@ multi_param_msg <- function(data_arg, stns, params) {
   ))
   
   ## Is the data anything other than a tibble?
-  if(class(data_arg)[1] != "tbl_df"){
+  if (!inherits(data_arg, "tbl_df")) {
     return(
       cli::cat_line(paste0(crayon::red(cli::symbol$cross)," ", stns, collapse = "\n"))
       )
